Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(626)

Unified Diff: content/browser/intents/intent_injector.h

Issue 8934011: Rename IntentsHost -> WebIntentsDispatcher and IntentsDispatcher -> WebIntentsHost. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge to head Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/intents/intent_injector.h
diff --git a/content/browser/intents/intent_injector.h b/content/browser/intents/intent_injector.h
index 87c743b854a7e084900f7a528ee157d5ff56ce24..2481ecf2e4cc0a45b42936d78b98b4aa6bf77825 100644
--- a/content/browser/intents/intent_injector.h
+++ b/content/browser/intents/intent_injector.h
@@ -13,7 +13,7 @@
#include "webkit/glue/web_intent_reply_data.h"
namespace content {
-class IntentsHost;
+class WebIntentsDispatcher;
}
namespace webkit_glue {
@@ -44,11 +44,11 @@ class CONTENT_EXPORT IntentInjector : public TabContentsObserver {
// Sets the intent data to be injected. Call after the user has selected a
// service to pass the intent data to that service.
// |source_tab| is a sender to use to communicate to the source tab. The
// caller must ensure that SourceTabContentsDestroyed is called when this
// object becomes unusable.
// |intent| is the intent data from the source
- void SetIntent(content::IntentsHost* source_tab,
+ void SetIntent(content::WebIntentsDispatcher* intents_dispatcher,
const webkit_glue::WebIntentData& intent);
private:
@@ -63,7 +63,7 @@ class CONTENT_EXPORT IntentInjector : public TabContentsObserver {
scoped_ptr<webkit_glue::WebIntentData> source_intent_;
// Weak pointer to the message forwarder to the tab invoking the intent.
- content::IntentsHost* source_tab_;
+ content::WebIntentsDispatcher* intents_dispatcher_;
DISALLOW_COPY_AND_ASSIGN(IntentInjector);
};
« no previous file with comments | « chrome/browser/ui/intents/web_intent_picker_controller_browsertest.cc ('k') | content/browser/intents/intent_injector.cc » ('j') | no next file with comments »
@@ -44,11 +44,11 @@ class CONTENT_EXPORT IntentInjector : public TabContentsObserver {
// Sets the intent data to be injected. Call after the user has selected a
// service to pass the intent data to that service.
- // |source_tab| is a sender to use to communicate to the source tab. The
- // caller must ensure that SourceTabContentsDestroyed is called when this
+ // |intents_dispatcher| is a sender to use to communicate to the source tab.
+ // The caller must ensure that SourceTabContentsDestroyed is called when this
// object becomes unusable.
// |intent| is the intent data from the source

Powered by Google App Engine
This is Rietveld 408576698